Class: Spotlight::Install

Inherits:
Rails::Generators::Base
  • Object
show all
Defined in:
lib/generators/spotlight/install_generator.rb

Overview

spotlight:install generator

Instance Method Summary collapse

Instance Method Details

#add_controller_mixinObject



75
76
77
78
79
# File 'lib/generators/spotlight/install_generator.rb', line 75

def add_controller_mixin
  inject_into_file 'app/controllers/application_controller.rb', after: 'include Blacklight::Controller' do
    "\n  include Spotlight::Controller\n"
  end
end

#add_example_catalog_controllerObject



118
119
120
# File 'lib/generators/spotlight/install_generator.rb', line 118

def add_example_catalog_controller
  copy_file 'catalog_controller.rb', 'app/controllers/catalog_controller.rb'
end

#add_helperObject



81
82
83
84
85
86
# File 'lib/generators/spotlight/install_generator.rb', line 81

def add_helper
  copy_file 'spotlight_helper.rb', 'app/helpers/spotlight_helper.rb'
  inject_into_file 'app/helpers/application_helper.rb', after: 'module ApplicationHelper' do
    "\n  include SpotlightHelper"
  end
end

#add_js_rails6Object

we’re not using webpacker, so we need to re-add sprockets functionality



14
15
16
17
18
19
# File 'lib/generators/spotlight/install_generator.rb', line 14

def add_js_rails6
  return unless Rails.version.to_i == 6

  # By default rails generates javascript_pack_tag, we'll change this to javascript_include_tag
  gsub_file 'app/views/layouts/application.html.erb', /pack/, 'include'
end

#add_mailer_defaultsObject



139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/generators/spotlight/install_generator.rb', line 139

def add_mailer_defaults
  if options[:mailer_default_url_host].present?
    say 'Injecting a placeholder config.action_mailer.default_url_options; be sure to update it for your environment', :yellow
    insert_into_file 'config/application.rb', after: "< Rails::Application\n" do
      <<-EOF
      config.action_mailer.default_url_options = { host: "#{options[:mailer_default_url_host]}", from: "noreply@example.com" }
      EOF
    end
  else
    say 'Please add a default configuration config.action_mailer.default_url_options for your environment', :red
  end
end

#add_manifestObject



21
22
23
24
# File 'lib/generators/spotlight/install_generator.rb', line 21

def add_manifest
  append_to_file 'app/assets/javascripts/application.js', "\n//= require_tree .\n"
  append_to_file 'app/assets/config/manifest.js', "\n//= link spotlight/manifest.js"
end

#add_model_mixinObject



88
89
90
91
92
93
94
95
96
# File 'lib/generators/spotlight/install_generator.rb', line 88

def add_model_mixin
  if File.exist? File.expand_path('app/models/solr_document.rb', destination_root)
    inject_into_file 'app/models/solr_document.rb', after: 'include Blacklight::Solr::Document' do
      "\n  include Spotlight::SolrDocument\n"
    end
  else
    say 'Unable to find SolrDocument class; add `include Spotlight::SolrDocument` to the class manually'
  end
end

#add_oembedObject



130
131
132
133
134
135
136
137
# File 'lib/generators/spotlight/install_generator.rb', line 130

def add_oembed
  unless Bundler.locked_gems.dependencies.key? 'blacklight-oembed'
    gem 'blacklight-oembed', '~> 1.0'
    bundle_install
  end
  generate 'blacklight_oembed:install'
  copy_file 'config/initializers/oembed.rb'
end

#add_osd_viewerObject



122
123
124
125
126
127
128
# File 'lib/generators/spotlight/install_generator.rb', line 122

def add_osd_viewer
  unless Bundler.locked_gems.dependencies.key? 'blacklight-gallery'
    gem 'blacklight-gallery', '~> 4.0'
    bundle_install
  end
  generate 'blacklight_gallery:install'
end

#add_roles_to_userObject



69
70
71
72
73
# File 'lib/generators/spotlight/install_generator.rb', line 69

def add_roles_to_user
  inject_into_file 'app/models/user.rb', after: 'include Blacklight::User' do
    "\n  include Spotlight::User\n"
  end
end

#add_search_builder_mixinObject



108
109
110
111
112
113
114
115
116
# File 'lib/generators/spotlight/install_generator.rb', line 108

def add_search_builder_mixin
  if File.exist? File.expand_path('app/models/search_builder.rb', destination_root)
    inject_into_file 'app/models/search_builder.rb', after: "include Blacklight::Solr::SearchBuilderBehavior\n" do
      "\n  include Spotlight::SearchBuilder\n"
    end
  else
    say 'Unable to find SearchBuilder class; add `include Spotlight::SearchBuilder` to the class manually.'
  end
end

#add_solr_config_resourcesObject



156
157
158
159
# File 'lib/generators/spotlight/install_generator.rb', line 156

def add_solr_config_resources
  copy_file '.solr_wrapper.yml', '.solr_wrapper.yml'
  directory 'solr'
end

#add_solr_indexing_mixinObject



98
99
100
101
102
103
104
105
106
# File 'lib/generators/spotlight/install_generator.rb', line 98

def add_solr_indexing_mixin
  if File.exist? File.expand_path('app/models/solr_document.rb', destination_root)
    inject_into_file 'app/models/solr_document.rb', after: "include Spotlight::SolrDocument\n" do
      "\n  include #{options[:solr_update_class]}\n"
    end
  else
    say "Unable to find SolrDocument class; add `include #{options[:solr_update_class]}` to the class manually"
  end
end

#add_translationsObject



168
169
170
# File 'lib/generators/spotlight/install_generator.rb', line 168

def add_translations
  copy_file 'config/initializers/translation.rb'
end

#assetsObject



64
65
66
67
# File 'lib/generators/spotlight/install_generator.rb', line 64

def assets
  copy_file 'spotlight.scss', 'app/assets/stylesheets/spotlight.scss'
  copy_file 'spotlight.js', 'app/assets/javascripts/spotlight.js'
end

#configure_loggingObject



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/generators/spotlight/install_generator.rb', line 172

def configure_logging
  insert_into_file 'config/application.rb', after: "< Rails::Application\n" do
    <<-EOF
    # Logging
    if ENV["RAILS_LOG_TO_STDOUT"].present?
      config.log_level = :debug
      config.log_formatter = ::Logger::Formatter.new
      # log to stdout
      logger               = ActiveSupport::Logger.new(STDOUT)
      logger.formatter     = config.log_formatter
      config.logger        = ActiveSupport::TaggedLogging.new(logger)
      # Print deprecation notices to the Rails logger.
      config.active_support.deprecation = :log
      # Raise an error on page load if there are pending migrations.
      config.active_record.migration_error = :page_load
      # Highlight code that triggered database queries in logs.
      config.active_record.verbose_query_logs = true
    end
    EOF
  end
end

#friendly_idObject



34
35
36
37
38
# File 'lib/generators/spotlight/install_generator.rb', line 34

def friendly_id
  gem 'friendly_id'
  bundle_install
  generate 'friendly_id'
end

#generate_configObject



152
153
154
# File 'lib/generators/spotlight/install_generator.rb', line 152

def generate_config
  directory 'config'
end

#generate_devise_invitableObject



161
162
163
164
165
166
# File 'lib/generators/spotlight/install_generator.rb', line 161

def generate_devise_invitable
  gem 'devise_invitable'
  bundle_install
  generate 'devise_invitable:install'
  generate 'devise_invitable', 'User'
end

#inject_spotlight_routesObject



26
27
28
29
30
31
32
# File 'lib/generators/spotlight/install_generator.rb', line 26

def inject_spotlight_routes
  route "mount Spotlight::Engine, at: 'spotlight'"
  gsub_file 'config/routes.rb', /^\s*root.*/ do |match|
    '#  ' + match.strip + ' # replaced by spotlight root path'
  end
  route "root to: 'spotlight/exhibits#index'"
end

#paper_trailObject



47
48
49
# File 'lib/generators/spotlight/install_generator.rb', line 47

def paper_trail
  generate 'paper_trail:install'
end

#riiifObject



40
41
42
43
44
45
# File 'lib/generators/spotlight/install_generator.rb', line 40

def riiif
  gem 'riiif'
  Bundler.with_clean_env { run 'bundle install' }
  route "mount Riiif::Engine => '/images', as: 'riiif'"
  copy_file 'config/initializers/riiif.rb'
end

#sitemapsObject



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/generators/spotlight/install_generator.rb', line 51

def sitemaps
  gem 'sitemap_generator'

  bundle_install

  copy_file 'config/sitemap.rb', 'config/sitemap.rb'

  say <<~EOS, :red
    Added a default sitemap_generator configuration in config/sitemap.rb; please
    update the default host to match your environment
  EOS
end