Class: Spotlight::CatalogController
- Inherits:
-
CatalogController
- Object
- ApplicationController
- CatalogController
- Spotlight::CatalogController
- Includes:
- Blacklight::Catalog, Catalog, Spotlight::Concerns::ApplicationController, Spotlight::Concerns::CatalogSearchContext
- Defined in:
- app/controllers/spotlight/catalog_controller.rb
Overview
Spotlight’s catalog controller. Note that this subclasses the host application’s CatalogController to get its configuration, partial overrides, etc rubocop:disable Metrics/ClassLength
Direct Known Subclasses
Instance Method Summary collapse
- #admin ⇒ Object
-
#autocomplete ⇒ Object
“id_ng” and “full_title_ng” should be defined in the Solr core’s schema.xml.
- #edit ⇒ Object
- #make_private ⇒ Object
- #make_public ⇒ Object
- #manifest ⇒ Object
- #show ⇒ Object
- #update ⇒ Object
Methods included from Catalog
#add_facet_visibility_field, #render_curator_actions?
Methods included from SearchHelper
#search_service, #search_service_context
Methods included from Base
#autocomplete_json_response, #autocomplete_json_response_for_document, #blacklight_config, #controller_tracking_method
Methods included from Config
#exhibit_specific_blacklight_config
Methods included from Spotlight::Concerns::ApplicationController
#enabled_in_spotlight_view_type_configuration?, #field_enabled?
Methods included from Controller
#blacklight_config, #current_exhibit, #current_masthead, #current_masthead=, #current_site, #default_url_options, #exhibit_masthead?, #exhibit_search_action_url, #exhibit_search_facet_path, #resource_masthead?, #search_action_url, #search_facet_path, #search_state, #set_exhibit_locale_scope, #set_locale
Instance Method Details
#admin ⇒ Object
72 73 74 75 76 77 78 79 80 81 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 72 def admin t(:'spotlight.curation.sidebar.header'), exhibit_dashboard_path(@exhibit) t(:'spotlight.curation.sidebar.items'), admin_exhibit_catalog_path(@exhibit) (@response,) = search_service.search_results @filters = params[:f] || [] respond_to do |format| format.html end end |
#autocomplete ⇒ Object
“id_ng” and “full_title_ng” should be defined in the Solr core’s schema.xml. It’s expected that these fields will be set up to have EdgeNGram filter setup within their index analyzer. This will ensure that this method returns results when a partial match is passed in the “q” parameter.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 60 def autocomplete @response, = search_service.search_results do |builder| builder.with(builder.blacklight_params.merge(search_field: Spotlight::Engine.config.autocomplete_search_field, public: true, rows: 100)) end respond_to do |format| format.json do render json: { docs: autocomplete_json_response(@response.documents) } end end end |
#edit ⇒ Object
83 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 83 def edit; end |
#make_private ⇒ Object
94 95 96 97 98 99 100 101 102 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 94 def make_private @document.make_private!(current_exhibit) @document.save respond_to do |format| format.html { redirect_back(fallback_location: [spotlight, current_exhibit, @document]) } format.json { render json: true } end end |
#make_public ⇒ Object
104 105 106 107 108 109 110 111 112 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 104 def make_public @document.make_public!(current_exhibit) @document.save respond_to do |format| format.html { redirect_back(fallback_location: [spotlight, current_exhibit, @document]) } format.json { render json: true } end end |
#manifest ⇒ Object
114 115 116 117 118 119 120 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 114 def manifest if @document.uploaded_resource? render json: Spotlight::IiifManifestPresenter.new(@document, self).iiif_manifest_json else head :not_found end end |
#show ⇒ Object
48 49 50 51 52 53 54 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 48 def show super authenticate_user! && (:curate, current_exhibit) if @document.private? current_exhibit (@document) end |
#update ⇒ Object
85 86 87 88 89 90 91 92 |
# File 'app/controllers/spotlight/catalog_controller.rb', line 85 def update @document.update(current_exhibit, solr_document_params) @document.save try_solr_commit! redirect_to polymorphic_path([current_exhibit, @document]) end |